package EFS::CLI::Business;

use strict;
use warnings;
use English;

use base q{EFS::CLI};
use base q{EFS::DBI};

use Params::Validate qw( :all );

sub define {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name        => { type => SCALAR },
        description => { type => SCALAR },
    });

    my $resultset = $class->get_resultset;

    my ($business) = $resultset->search({ name => $args{name} });

    if ( $business ) {

        STDOUT->print( qq{Business $args{name} is already defined.\n} );

        if ( $business->description ne $args{description} ) {
            $business->set_column( description => $args{description} );
            $business->update;
            STDOUT->print(
                qq{Updated description of business $args{name}\n},
            );
        }

    } else {

        $business = $resultset->create({
            name        => $args{name},
            description => $args{description},
        });

        STDOUT->print( qq{Defined business $args{name}\n} );

    }

    return $business;

}

sub undef {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR },
    });

    my $business = $class->retrieve_bynames_assert( name => $args{name} );

    if ( my @divisions = $business->divisions ) {
        die(
            qq{Unable to undef business $business, as it has the },
            qq{following divisions defined:\n\t},
            join(qq{\n\t}, map { $_->name } @divisions ), qq{\n},
        );
    }

    $business->attrs->delete_all;
    $business->delete;

    STDOUT->print( qq{Undefined business $args{name}\n} );

    return 1;

}

sub display {

    my $class = shift;

    my (%args) = validate( @_, {
        %EFS::CLI::validate_common,
        name => { type => SCALAR, optional => 1 },
    });

    my $resultset = $class->get_resultset;

    if ( not $args{name} ) {
        $class->display_objects( objects => [ $resultset->all ] );
        return 1;
    }

    my $business = $class->retrieve_bynames_assert( name => $args{name} );

    $class->display_objects( objects => [ $business ] );

    if ( my @attrs = $business->attrs ) {
        $attrs[0]->display_objects( objects => \@attrs );
    }

    if ( my @divisions = $business->divisions ) {
        $divisions[0]->display_objects( objects => \@divisions );
    }

    return 1;

}

sub history {

    my $class = shift;

    my (%args) = validate( @_, {
        name => { type => SCALAR },
        %EFS::CLI::validate_common,
        %EFS::CLI::History::validation_specs,
    });

    $args{business} = delete $args{name};

    return EFS::CLI::History->history(%args);

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
