package EFS::DBI::Result::PlatformInstance;

use strict;
use warnings;
use English;

use base q{EFS::DBI::Result};

__PACKAGE__->load_components( qw/+EFS::DBI::Prefix Core/ );

__PACKAGE__->table( q{platform_instance} );

__PACKAGE__->add_columns( qw( name platform backwards emulates ) );
__PACKAGE__->add_columns(
    id => { __PACKAGE__->get_id_column_attrs },
);
__PACKAGE__->set_primary_key( q{id} );
__PACKAGE__->sequence( q{platform_instance_seq} );

__PACKAGE__->belongs_to( platform => q{EFS::DBI::Result::Platform} );

__PACKAGE__->belongs_to( backwards => q{EFS::DBI::Result::PlatformInstance} );
__PACKAGE__->belongs_to( emulates => q{EFS::DBI::Result::PlatformInstance} );

__PACKAGE__->has_many( aliases => q{EFS::DBI::Result::PlatformInstanceAlias} );

sub forwards {
    my $self = shift;
    return $self->get_resultset->search({ backwards => $self->id });
}

sub emulators {
    my $self = shift;
    return $self->get_resultset->search({ emulates => $self->id });
}

sub installs {
    my $self = shift;
    my $install_rs = $self->get_resultset( q{Install} );
    return $install_rs->search({ name => $self->name });
}

sub children_all {
    my $self = shift;
    my @emulates = $self->emulates_all;
    my @children = ( @emulates, $self->backwards_all );
    foreach my $emulates ( @emulates ) {
        push( @children, $emulates->backwards_all );
    }
    return @children;
}

sub backwards_all {
    my $self = shift;
    my @backwards = ();
    while ( $self = $self->backwards ) {
        push( @backwards, $self );
    }
    return @backwards;
}

sub emulates_all {
    my $self = shift;
    my @emulates = ();
    while ( $self = $self->emulates ) {
        push( @emulates, $self );
    }
    return @emulates;
}

sub get_alias_installs {

    my $self = shift;
    my $release = shift;

    my @aliases = $self->aliases;
    my @installs = $release->installs;

    my @results = ();

    foreach my $alias ( @aliases ) {
        foreach my $install ( @installs ) {
            if ( $install->name eq $alias->name ) {
                push @results, $install;
            }
        }
    }

    return @results;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
