package EFS::DBI::ResultSet::EFSServer;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );
use Readonly;

Readonly my %IS_VALID_HOSTTYPE => map { ( $_ => 1 ) } qw{ dev test prod };

sub validate_data {

    my $class = shift;
    my %data = @_;

    if ( exists $data{efsserver} and defined $data{efsserver}
            and $data{efsserver} !~ m/\A [-\w\.]+ \z/msx ) {
        die(
            qq{Invalid efsserver name '$data{efsserver}'\n},
            q{Must consist solely of alphanumeric characters, },
            qq{underscores, dashes and/or dots\n}
        );
    }

    if ( exists $data{hosttype}
            and not exists $IS_VALID_HOSTTYPE{ $data{hosttype} } ) {
        die(
            qq{Invalid efsserver hosttype '$data{hosttype}'\n},
            q{Must be one of: },
            join( q{, }, keys %IS_VALID_HOSTTYPE ),
            qq{.\n},
        );
    }

    return 1;

}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        name => { type => SCALAR },
    });

    my ($efsserver) = $self->search({ name => $args{name} });

    if ( not $efsserver ) {
        die qq{No such efsserver '$args{name}'\n};
    }

    return $efsserver;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
