package EFS::DBI::ResultSet::Hostclass;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

sub validate_data {

    my $class = shift;
    my %data  = @_;

    return 1 unless exists $data{hostclass};

        ## no critic ProhibitEnumeratedClasses
        # we really do want a-z here; [:lower:] would be effected by locale
    $data{hostclass} =~ m/\A [-+_a-z0-9]+ \z/msx || die(
        qq{Invalid hostclass '$data{hostclass}'\n},
        q{Must consist solely of },
        qq{lower case letters and numbers (a-z, 0-9),\n},
        qq{dash (-), plus (+) and the underscore (_)\n},
    );

    return;

}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        name => { type => SCALAR },
    });

    my ($hostclass) = $self->search({ name => $args{name} });

    if ( not $hostclass ) {
      die qq{No such hostclass '$args{name}'\n};
    }

    return $hostclass;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
