package EFS::DBI::ResultSet::Parameter;

use strict;
use warnings;
use English;

use base q{EFS::DBI::ResultSet};

use Params::Validate qw( :all );

our @parameter_names = qw( root_domain );

sub validate_data {

    my $class = shift;
    my %data  = @_;

    if ( exists $data{name} ) {
        if ( not grep { $data{name} eq $_ } @parameter_names ) {
            die(
                qq{Invalid parameter name '$data{name}'\n},
                qq{Must be one of the following:\n\t},
                join( qq{\n\t}, @parameter_names ), qq{\n},
            );
        }
    }

    return 1;

}

sub configured {

    my $self = shift;
    my $name = shift;

    my ($parameter) = $self->search({ name => $name });

    if ( $parameter && $parameter->value ) {
        return $parameter->value;
    } else {
        return;
    }

}

sub retrieve_bynames_assert {

    my $self = shift;

    my (%args) = validate( @_, {
        name => { type => SCALAR },
    });

    my ($parameter) = $self->search({ name => $args{name} });

    if ( not $parameter ) {
        die qq{No such parameter '$args{name}'\n};
    }

    return $parameter;

}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
