package EFS::Diststate::Project;

use strict;
use warnings;
use English;

use Moose;
use Params::Validate qw( :all );

extends qw(EFS::Diststate);
use EFS::Diststate::Release;

has project => (
    is => 'rw',
);

has release_diststate => (
    is => 'rw',
);


sub BUILD {

    my ($self,@args) = @_;

    my (%args) = validate( @args, {
        project => {
            type => OBJECT,
            isa  => q{EFS::DBI::Result::Project}
        },
    });

    my $project = $self->project( $args{project} );

    # For this purpose, "$release" may refer to a release or
    # a releasealias; the results are the same
    foreach my $release ( $project->releases, $project->releasealiases ) {
        $self->release_diststate->{ $release->name } =
            $release->get_diststate;
    }

    return;

}

sub related_item { return shift->get_project }

sub subitem_diststates {
    my ( $self ) = @_;
    return values %{ $self->release_diststate };
}

sub projects_needing_update {
    my $self = shift;

    my (%args) = validate( @_, {
        cells => { type => ARRAYREF, optional => 1 },
    });

    if ( $self->needs_update(%args) ) {
        return $self;
    }
    else {
        return ();
    }
}

sub projects_updated {
    my $self = shift;

    my (%args) = validate( @_, {
        cells => { type => ARRAYREF, optional => 1 },
    });

    if ( $self->has_been_updated(%args) ) {
        return $self;
    }
    else {
        return ();
    }
}

sub _subitem_type { return q{release} }


1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
