package EFS::Proc::ProcessTable;

use strict;
use warnings;
use English;

use Moose;

use EFS::Proc::Process;

has q{command} => (
    is      => q{rw},
    isa     => q{Str},
    default => q{ps aux},
);

has q{table} => (
    is  => q{rw},
    isa => q{ArrayRef[EFS::Proc::Process]},
);

sub BUILD {

    my $self = shift;

    my @ps = $self->_get_ps;

    my @processes = map { EFS::Proc::Process->new( $self->_parse_ps( $_ ) ) } @ps;

    $self->table( \@processes );

    return $self;

}

sub _get_ps {

    my $self = shift;

    my $command = $self->command;

    my @ps = qx{ $command };
    $CHILD_ERROR and die qq{Unable to run ps command\n};

    shift @ps;

    return @ps;

}

sub _parse_ps {

    my $self = shift;
    my $ps   = shift;

    $ps =~ s{^\s+}{}msx;

    my ($pid,$pctcpu,$pctmem,$size,$rss) = (split m{\s+}msx, $ps)[1..5];

    return (
        pid    => $pid,
        pctcpu => $pctcpu,
        pctmem => $pctmem,
        size   => $size,
        rss    => $rss,
    );

}

no Moose;
__PACKAGE__->meta->make_immutable;
1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
