
create table "region" (
    "id"		int             not null,
    "name"              varchar(24)     not null,
    "description"       varchar(1024)   not null,
    constraint "region_pk" primary key ("id"),
    constraint "region_idx1" unique ("name")
);

create table "region_attrs" (
    "id"	int         	not null,
    "region"    int             not null,
    "name"      varchar(256)    not null,
    "value"     varchar(512)    not null,
    constraint "region_attrs_pk" primary key ("id"),
    constraint "region_attrs_idx1" unique ("region","name"),
    constraint "region_attrs_fk1"
        foreign key ("region") references "region"("id")
);

create table "campus" (
    "id"              	int     	not null,
    "region"		int	        not null,
    "name"		varchar(64)	not null,
    "description"       varchar(1024)   not null,
    constraint "campus_pk" primary key ("id"),
    constraint "campus_idx1" unique ("name"),
    constraint "campus_fk1"
        foreign key ("region") references "region"("id")
);

create table "campus_attrs" (
    "id"     int	    not null,
    "campus" int            not null,
    "name"   varchar(256)   not null,
    "value"  varchar(512)   not null,
    constraint "campus_attrs_pk" primary key ("id"),
    constraint "campus_attrs_idx1" unique ("campus","name"),
    constraint "campus_attrs_fk1"
        foreign key ("campus") references "campus"("id")
);

create table "location" (
    "id"                int             not null,
    "campus"            int             not null,
    "name"              varchar(128)    not null,
    "description"       varchar(1024)   not null,
    constraint "location_pk" primary key ("id"),
    constraint "location_idx1" unique ("name"),
    constraint "location_fk1"
        foreign key ("campus") references "campus"("id")
);

create table "location_attrs" (
    "id"		int     	not null,
    "location"          int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "location_attrs_pk" primary key ("id"),
    constraint "location_attrs_idx1" unique ("location","name"),
    constraint "location_attrs_fk1"
        foreign key ("location") references "location"("id")
);

create table "cell" (
    "id"		int             not null,
    "location"          int             not null,
    "name"              varchar(256)    not null,
    "celltype"          varchar(8)      not null,
    "fstype"            varchar(8)      not null,
    "parentcell"        int	        null,
    "hidden"            numeric(1)      default 0,
    "disabled"          numeric(1)      default 0,
    constraint "cell_pk" primary key ("id"),
    constraint "cell_idx1" unique ("name"),
    constraint "cell_fk1" foreign key ("location") references "location"("id"),
    constraint "cell_fk2" foreign key ("parentcell") references "cell"("id")
);

create table "cell_attrs" (
    "id"		int             not null,
    "cell"              int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "cell_attrs_pk" primary key ("id"),
    constraint "cell_attrs_idx1" unique ("cell","name"),
    constraint "cell_attrs_fk1" foreign key ("cell") references "cell"("id")
);

create table "fileserver" (
    "id"		int             not null,
    "cell"              int    	        not null,
    "name"              varchar(128)    not null,
    constraint "fileserver_pk" primary key ("id"),
    constraint "fileserver_idx1" unique ("name"),
    constraint "fileserver_fk1" foreign key ("cell") references "cell"("id")
);

create table "fileserver_attrs" (
    "id"		int             not null,
    "fileserver"        int	        not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "fileserver_attrs_pk" primary key ("id"),
    constraint "fileserver_attrs_idx1" unique ("fileserver","name"),
    constraint "fileserver_attrs_fk1"
        foreign key ("fileserver") references "fileserver"("id")
);

create table "fileshare" (
    "id"		int             not null,
    "fileserver"        int    	        not null,
    "name"              varchar(128)    not null,
    "filetype"          varchar(4)      null,
    constraint "fileshare_pk" primary key ("id"),
    constraint "fileshare_idx1" unique ("fileserver","name"),
    constraint "fileshare_fk1"
        foreign key ("fileserver") references "fileserver"("id")
);

create table "fileshare_attrs" (
    "id"		int             not null,
    "fileshare"         int    	        not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "fileshare_attrs_pk" primary key ("id"),
    constraint "fileshare_attrs_idx1" unique ("fileshare","name"),
    constraint "fileshare_attrs_fk1"
        foreign key ("fileshare") references "fileshare"("id")
);

create table "fileqtree" (
    "id"		int             not null,
    "fileshare"         int    	        not null,
    "name"              varchar(128)    not null,
    constraint "fileqtree_pk" primary key ("id"),
    constraint "fileqtree_idx1" unique ("fileshare","name"),
    constraint "fileqtree_fk1"
        foreign key ("fileshare") references "fileshare"("id")
);

create table "fileqtree_attrs" (
    "id"		int             not null,
    "fileqtree"         int    	        not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "fileqtree_attrs_pk" primary key ("id"),
    constraint "fileqtree_attrs_idx1" unique ("fileqtree","name"),
    constraint "fileqtree_attrs_fk1"
        foreign key ("fileqtree") references "fileqtree"("id")
);

create table "efsserver" (
    "id"	int             not null,
    "name"     	varchar(256) 	not null,
    "hosttype"	varchar(8) 	not null,
    "disabled"  numeric(1)      default 0,
    constraint "efsserver_pk" primary key ("id"),
    constraint "efsserver_idx1" unique ("name")
);

create table "efsserver_cell" (
    "id"		int     not null,
    "efsserver"         int     not null,
    "cell"     	      	int     not null,
    constraint "efsserver_cell_pk" primary key ("id"),
    constraint "efsserver_cell_idx1" unique ("efsserver","cell"),
    constraint "efsserver_cell_fk1"
        foreign key ("efsserver") references "efsserver"("id"),
    constraint "efsserver_cell_fk2"
        foreign key ("cell") references "cell"("id")
);

create table "efsserver_attrs" (
    "id"		int             not null,
    "efsserver"         int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "efsserver_attrs_pk" primary key ("id"),
    constraint "efsserver_attrs_idx1" unique ("efsserver","name"),
    constraint "efsserver_attrs_fk1"
        foreign key ("efsserver") references "efsserver"("id")
);

create table "metaproj" (
    "id"		int             not null,
    "name"        	varchar(32)     not null,
    "username"          varchar(8)      not null,
    "groupname"         varchar(8)      not null,
    "owner_list"	varchar(256)	not null,
    "notify_list"	varchar(256)	null,
    "noworldaccess"	numeric(1)      null,
    "distgroup"         varchar(8)      null,
    constraint "metaproj_pk" primary key ("id"),
    constraint "metaproj_idx1" unique ("name")
);

create table "metaproj_attrs" (
    "id"		int             not null,
    "metaproj"		int	        not null,
    "name"		varchar(256)	not null,
    "value"		varchar(512)	not null,
    constraint "metaproj_attrs_pk" primary key ("id"),
    constraint "metaproj_attrs_idx1" unique ("metaproj","name"),
    constraint "metaproj_attrs_fk1"
        foreign key ("metaproj") references "metaproj"("id")
);

create table "project" (
    "id"		int             not null,
    "metaproj"    	int             not null,
    "name"        	varchar(64) 	not null,
    "cell"        	int             not null,
    "movelock"		varchar(1024)	null,
    "owner_list"	varchar(256)	null,
    "notify_list"	varchar(256)	null,
    "noworldaccess"	numeric(1)      null,
    "distgroup"         varchar(8)      null,
    constraint "project_pk" primary key ("id"),
    constraint "project_idx1" unique ("metaproj","name"),
    constraint "project_fk1"
        foreign key ("metaproj") references "metaproj"("id"),
    constraint "project_fk2"
        foreign key ("cell") references "cell"("id")
);

create table "project_attrs" (
    "id"		int             not null,
    "project"           int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "project_attrs_pk" primary key ("id"),
    constraint "project_attrs_idx1" unique ("project","name"),
    constraint "project_attrs_fk1"
        foreign key ("project") references "project"("id")
);

create table "release" (
    "id"		int             not null,
    "project"     	int 	        not null,
    "name"        	varchar(128) 	not null,
    "stage"       	varchar(64) 	default 'dev',
    "locked"      	numeric(1),
    "destroyed"   	date,
    "packaged"   	date,
    "uploaded"   	date,
    "downloaded"   	date,
    "noworldaccess"	numeric(1)      null,
    "distgroup"         varchar(8)      null,
    "cloneof"           int             null,
    constraint "release_pk" primary key ("id"),
    constraint "release_idx1" unique ("project","name"),
    constraint "release_fk1"
        foreign key ("project") references "project"("id"),
    constraint "release_fk2"
        foreign key ("cloneof") references "release"("id")
);

create table "release_attrs" (
    "id"		int             not null,
    "release"           int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "release_attrs_pk" primary key ("id"),
    constraint "release_attrs_idx1" unique ("release","name"),
    constraint "release_attrs_fk1"
        foreign key ("release") references "release"("id")
);

create table "releasealias" (
    "id"		int             not null,
    "project"           int             not null,
    "name"              varchar(128)    not null,
    "target"            varchar(128)    not null,
    constraint "releasealias_pk" primary key ("id"),
    constraint "releasealias_idx1" unique ("project","name"),
    constraint "releasealias_fk1"
        foreign key ("project") references "project"("id")
);

create table "releasealias_attrs" (
    "id"		int             not null,
    "releasealias"      int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "releasealias_attrs_pk" primary key ("id"),
    constraint "releasealias_attrs_idx1" unique ("releasealias","name"),
    constraint "releasealias_attrs_fk1"
        foreign key ("releasealias") references "releasealias"("id")
);

create table "releasealias_cellstate" (
    "id"		int             not null,
    "releasealias"	int	        not null,
    "cell"		int	        not null,
    "target"		varchar(128)	not null,
    constraint "releasealias_cellstate_pk" primary key ("id"),
    constraint "releasealias_cellstate_idx1" unique ("releasealias","cell"),
    constraint "releasealias_cellstate_fk1"
        foreign key ("releasealias") references "releasealias"("id"),
    constraint "releasealias_cellstate_fk2"
        foreign key ("cell") references "cell"("id")
);

create table "dependency_release" (
    "id"                 int            not null,
    "dependent_release"  int 	        not null,
    "release"            int 	        not null,
    "type"               varchar(32) 	default 'runtime',
    constraint "dependency_release_pk" primary key ("id"),
    constraint "dependency_release_idx1"
        unique ("dependent_release","release","type"),
    constraint "dependency_release_fk1"
        foreign key ("dependent_release") references "release"("id"),
    constraint "dependency_release_fk2"
        foreign key ("release") references "release"("id")
);

create table "dependency_releasealias" (
    "id"                 int            not null,
    "dependent_release"  int 	        not null,
    "releasealias"       int 	        not null,
    "type"               varchar(32) 	default 'runtime',
    constraint "dependency_releasealias_pk" primary key ("id"),
    constraint "dependency_releasealias_idx1"
        unique ("dependent_release","releasealias","type"),
    constraint "dependency_releasealias_fk1"
        foreign key ("dependent_release") references "release"("id"),
    constraint "dependency_releasealias_fk2"
        foreign key ("releasealias") references "releasealias"("id")
);

create table "install" (
    "id"		int             not null,
    "release"		int 	        not null,
    "name"       	varchar(128) 	not null,
    "spaceused"  	numeric(22) 	default 0,
    "filecount"  	numeric(22) 	default 0,
    "dircount"   	numeric(22) 	default 0,
    "linkcount"  	numeric(22) 	default 0,
    "checksum"   	varchar(128)	null,
    "checktime"		numeric(22)	default 0,
    "cloneof"           int             null,
    constraint "install_pk" primary key ("id"),
    constraint "install_idx1" unique ("release","name"),
    constraint "install_fk1" foreign key ("release") references "release"("id"),
    constraint "install_fk2" foreign key ("cloneof") references "install"("id")
);

create table "install_attrs" (
    "id"		int             not null,
    "install"           int    	        not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "install_attrs_pk" primary key ("id"),
    constraint "install_attrs_idx1" unique ("install","name"),
    constraint "install_attrs_fk1"
        foreign key ("install") references "install"("id")
);

create table "install_cellstate" (
    "id"		int             not null,
    "install"           int    	        not null,
    "cell"              int    	        not null,
    "updatetime"	numeric(22)	default 0,
    constraint "install_cellstate_pk" primary key ("id"),
    constraint "install_cellstate_idx1" unique ("install","cell"),
    constraint "install_cellstate_fk1"
        foreign key ("install") references "install"("id"),
    constraint "install_cellstate_fk2"
        foreign key ("cell") references "cell"("id")
);

create table "install_auditstate" (
    "id"		int             not null,
    "install"           int    	        not null,
    "name"              varchar(256)    not null,
    "audittime"	        numeric(22)	default 0,
    "status"		numeric(1)	default 0,
    constraint "install_auditstate_pk" primary key ("id"),
    constraint "install_auditstate_idx1" unique ("install","name"),
    constraint "install_auditstate_fk1"
        foreign key ("install") references "install"("id")
);

create table "grouprights" (
    "id"                int             not null,
    "metaproj"          int             not null,
    "role"              varchar(64)     not null,
    "groupname"		varchar(8)	not null,
    constraint "grouprights_pk" primary key ("id"),
    constraint "grouprights_idx1" unique ("metaproj","role","groupname"),
    constraint "grouprights_fk1"
        foreign key ("metaproj") references "metaproj"("id")
);

create table "userrights" (
    "id"                int             not null,
    "metaproj"          int             not null,
    "role"              varchar(64)     not null,
    "username"		varchar(8)	not null,
    constraint "userrights_pk" primary key ("id"),
    constraint "userrights_idx1" unique ("metaproj","role","username"),
    constraint "userrights_fk1"
        foreign key ("metaproj") references "metaproj"("id")
);

create table "platform" (
    "id"		int             not null,
    "name"              varchar(64)     not null,
    "backwards"         int             null,
    "emulates"          int             null,
    constraint "platform_pk" primary key ("id"),
    constraint "platform_idx1" unique ("name"),
    constraint "platform_fk1"
        foreign key ("backwards") references "platform"("id"),
    constraint "platform_fk2"
        foreign key ("emulates") references "platform"("id")
);

create table "platform_alias" (
    "id"		int             not null,
    "name"              varchar(64)     not null,
    "platform"          int             null,
    constraint "platform_alias_pk" primary key ("id"),
    constraint "platform_alias_idx1" unique ("name"),
    constraint "platform_alias_fk1"
        foreign key ("platform") references "platform"("id")
);

create table "platform_instance" (
    "id"		int             not null,
    "name"              varchar(64)     not null,
    "platform"          int             not null,
    "backwards"         int             null,
    "emulates"          int             null,
    constraint "platform_instance_pk" primary key ("id"),
    constraint "platform_instance_idx1" unique ("name"),
    constraint "platform_instance_fk1"
        foreign key ("platform") references "platform"("id"),
    constraint "platform_instance_fk2"
        foreign key ("backwards") references "platform_instance"("id"),
    constraint "platform_instance_fk3"
        foreign key ("emulates") references "platform_instance"("id")
);

create table "platform_instance_alias" (
    "id"		int             not null,
    "name"              varchar(64)     not null,
    "platforminstance"  int             null,
    constraint "platform_instance_alias_pk" primary key ("id"),
    constraint "platform_instance_alias_idx1" unique ("name"),
    constraint "platform_instance_alias_fk1"
        foreign key ("platforminstance") references "platform_instance"("id")
);

create table "business" (
    "id"                int             not null,
    "name"		varchar(24)	not null,
    "description"       varchar(1024)   not null,
    constraint "business_pk" primary key ("id"),
    constraint "business_idx1" unique ("name")
);

create table "business_attrs" (
    "id"		int             not null,
    "business"          int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "business_attrs_pk" primary key ("id"),
    constraint "business_attrs_idx1" unique ("business","name"),
    constraint "business_attrs_fk1"
        foreign key ("business") references "business"("id")
);

create table "division" (
    "id"		int             not null,
    "business"		int	        not null,
    "name"		varchar(64)	not null,
    "description"       varchar(1024)   not null,
    constraint "division_pk" primary key ("id"),
    constraint "division_idx1" unique ("name"),
    constraint "division_fk1"
        foreign key ("business") references "business"("id")
);

create table "division_attrs" (
    "id"		int             not null,
    "division"          int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "division_attrs_pk" primary key ("id"),
    constraint "division_attrs_idx1" unique ("division","name"),
    constraint "division_attrs_fk1"
        foreign key ("division") references "division"("id")
);

create table "pod" (
    "id"		int             not null,
    "location"		int	        not null,
    "name"		varchar(256)    not null,
    "description"       varchar(1024)   not null,
    constraint "pod_pk" primary key ("id"),
    constraint "pod_idx1" unique ("location","name"),
    constraint "pod_fk1"
        foreign key ("location") references "location"("id")
);

create table "pod_attrs" (
    "id"		int             not null,
    "pod"	        int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "pod_attrs_pk" primary key ("id"),
    constraint "pod_attrs_idx1" unique ("pod","name"),
    constraint "pod_attrs_fk1"
        foreign key ("pod") references "pod"("id")
);

create table "hostclass" (
    "id"                int             not null,
    "name"		varchar(128)	not null,
    "description"       varchar(1024)   not null,
    constraint "hostclass_pk" primary key ("id"),
    constraint "hostclass_idx1" unique ("name")
);

create table "hostclass_attrs" (
    "id"		int             not null,
    "hostclass"         int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "hostclass_attrs_pk" primary key ("id"),
    constraint "hostclass_attrs_idx1" unique ("hostclass","name"),
    constraint "hostclass_attrs_fk1"
        foreign key ("hostclass") references "hostclass"("id")
);

create table "cabinet" (
    "id"		int             not null,
    "location"		int	        not null,
    "name"		varchar(256)	not null,
    constraint "cabinet_pk" primary key ("id"),
    constraint "cabinet_idx1" unique ("name"),
    constraint "cabinet_fk1"
        foreign key ("location") references "location"("id")
);

create table "cabinet_attrs" (
    "id"		int             not null,
    "cabinet"           int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "cabinet_attrs_pk" primary key ("id"),
    constraint "cabinet_attrs_idx1" unique ("cabinet","name"),
    constraint "cabinet_attrs_fk1"
        foreign key ("cabinet") references "cabinet"("id")
);

create table "platform_build" (
    "id"		int             not null,
    "name"        	varchar(64) 	not null,
    "platform"    	int 	        not null,
    "kernel"		varchar(1024)	not null,
    "initrd"		varchar(1024)	not null,
    "options"		varchar(1024)	not null,
    constraint "platform_build_pk" primary key ("id"),
    constraint "platform_build_idx1" unique ("name"),
    constraint "platform_build_fk1"
        foreign key ("platform") references "platform"("id")
);

create table "platform_build_attrs" (
    "id"		int             not null,
    "platformbuild"     int             not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "platform_build_attrs_pk" primary key ("id"),
    constraint "platform_build_attrs_idx1" unique ("platformbuild","name"),
    constraint "platform_build_attrs_fk1"
        foreign key ("platformbuild") references "platform_build"("id")
);

create table "feature" (
    "id"		int             not null,
    "name"              varchar(64)     not null,
    "value"             varchar(1024)   not null,
    constraint "feature_pk" primary key ("id"),
    constraint "feature_idx1" unique ("name")
);

create table "ffrule" (
    "id"		int             not null,
    "name"              varchar(64)     not null,
    "regex"             varchar(256)    not null,
    "description"       varchar(1024)   not null,
    constraint "ffrule_pk" primary key ("id"),
    constraint "ffrule_idx1" unique ("name")
);

create table "parameter" (
    "id"		int             not null,
    "name"              varchar(64)     not null,
    "value"             varchar(1024)   not null,
    constraint "parameter_pk" primary key ("id"),
    constraint "parameter_idx1" unique ("name")
);

create table "sslserver" (
    "id"		int             not null,
    "type"              varchar(128) 	not null,
    "efsserver"         int             not null,
    constraint "sslserver_pk" primary key ("id"),
    constraint "sslserver_fk1"
        foreign key ("efsserver") references "efsserver"("id")
);

create table "home" (
    "id"		int             not null,
    "cell"              int    	        not null,
    "name"              varchar(128)    not null,
    "destroyed"   	date,
    constraint "home_pk" primary key ("id"),
    constraint "home_idx1" unique ("name"),
    constraint "home_fk1" foreign key ("cell") references "cell"("id")
);

create table "home_attrs" (
    "id"		int             not null,
    "home"              int	        not null,
    "name"              varchar(256)    not null,
    "value"             varchar(512)    not null,
    constraint "home_attrs_pk" primary key ("id"),
    constraint "home_attrs_idx1" unique ("home","name"),
    constraint "home_attrs_fk1"
        foreign key ("home") references "home"("id")
);

