#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Config;

use blib;
use EFS;

use lib q{test/lib};
use EFS::Test;
use EFS::Test::Config;

use Test::More tests => 9;
use IO::File;

my $config = EFS::Test::Config->new;
my $rwuser = $config->get_value( q{Database}, q{rwuser} );

my $ldc_efsserver = $config->get_value( q{LocalDevCell}, q{efsserver} );

SKIP: {

    if ( not $config->get_value( q{Security}, q{kerberos_realm} ) ) {
        skip q{Kerberos tests not configured}, 1;
    }

    ## no critic: RequireInterpolationOfMetachars
    my $krb5ccname = qq{/var/tmp/krb5_efstest_$PID};
    $ENV{KRB5CCNAME} = qq{FILE:$krb5ccname};
    system qq{kinit -k -t /var/kerberos/keytabs/efsops.keytab efsops};
    ok( $CHILD_ERROR == 0, q{Acquired efsops credentials for this test} );

}

ok( EFS::CLI::EFSServer->newkeys( bootstrap => 1 ), q{Boostrapped efsserver ssh keys} );

ok( EFS::CLI::EFSServer->purgekeys, q{Purged old keys} );

ok( EFS::CLI::EFSServer->newcerts, q{Boostrapped new SSL certificates} );

ok( EFS::CLI::EFSServer->purgecerts, q{Purged old SSL certificates} );

ok( EFS::CLI::EFSServer->newdbpw( bootstrap => 1 ), q{Bootstrapped new database password} );

my $io = IO::File->new(qq{/var/efs/etc/passwd/$rwuser}) ||
    die qq{Unable to open /var/efs/etc/passwd/$rwuser: $ERRNO\n};

my ($rwpass) = reverse <$io>;
chomp( $rwpass );

ok( $rwpass, q{Retrieved auto-generated rwuser password} );

my $save_config = EFS::Test::Config->new( { noexpand => 1 } );

ok(
    $save_config->set_value( q{Database}, q{rwpasswd}, $rwpass ),
    q{Saved rwuser password to test config}
);

ok( $save_config->save_file, q{Saved test config file} );

END {
    my $krb5ccname = qq{/var/tmp/krb5_efstest_$PID};
    if ( $krb5ccname && -f $krb5ccname ) {
        system q{kdestroy};
        $CHILD_ERROR and warn qq{Unable to destroy kerberos credentials\n};
    }
}
