#!/usr/bin/env perl
use strict;
use warnings;
use English;

use blib;
use EFS;

use lib q{test/lib};
use EFS::Test;

use Test::More;

## no critic: RequireInterpolationOfMetachars

my $config = EFS::Test::Config->new;
my $ldc_efsserver = $config->get_value( q{LocalDevCell}, q{efsserver} );

my $fstype = $config->get_value( q{Filesystem}, q{type} );

my $krb5ccname = qq{/var/tmp/krb5_efstest_$PID};

if ( $fstype eq q{afs} ) {
    plan skip_all => q{Fileqtrees are only initialized when testing NFS};
}

SKIP: {

    if ( not $config->get_value( q{Security}, q{kerberos_realm} ) ) {
        skip q{Kerberos tests not configured}, 1;
    }

    $ENV{KRB5CCNAME} = qq{FILE:$krb5ccname};
    system qq{kinit -k -t /var/kerberos/keytabs/efsops.keytab efsops};
    ok( $CHILD_ERROR == 0, q{Acquired efsops credentials for this test} );

}

ok( EFS::CLI::Fileqtree->init, q{Initialized all fileqtrees} );

done_testing();

END {
    if ( $krb5ccname && -f $krb5ccname ) {
        system q{kdestroy};
        $CHILD_ERROR and warn qq{Unable to destroy kerberos credentials\n};
    }
}

