#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Data::Dumper;

use blib;
use EFS;

use lib q{test/lib};
use EFS::Test;
use EFS::Test::Config;

use Test::More tests => 3;

# NOTE: This is far from complete.  There's a lot more to test here...

my $test = EFS::Test->new;
my $config = EFS::Test::Config->new;

my $ldc_name = $config->get_value( q{LocalDevCell}, q{name} );
my $root_domain = $config->get_value( q{Global}, q{root_domain} );

my $project_rs = EFS::DBI->get_resultset( q{Project} );
my $project = $project_rs->retrieve_bynames_assert(
    metaproj => q{efs},
    name     => q{config-database},
);

$test->efs_test_command(
    run_as  => q{efsops},
    command => q{efs dumpconfig database},
);

my @releases_after = $project->active_releases;

ok( $#releases_after == 0, q{Only one active release in efs/config-database} );

$test->run_as_efsops(
    q{Testing flat file database access via the EFS API},
    sub {

        my $dbvendor = EFS::DBI->get_db_vendor;

        if ( $dbvendor ne q{sqlite} ) {
            die qq{dbvendor should be 'sqlite', but is '$dbvendor'\n};
        }

        my $parameter_rs = EFS::DBI->get_resultset( q{Parameter} );

        my %parameters = (
            root_domain => $root_domain,
            database_type => q{test},
        );

        foreach my $name ( keys %parameters ) {

            my ($parameter) = $parameter_rs->search({ name => $name });

            if ( not $parameter ) {
                die qq{Unable to query parameter $name\n};
            }

            if ( $parameter->value ne $parameters{ $name } ) {
                die(
                    qq{Value of parameter $name is '}, $parameter->value, qq{'\n},
                    q{Should be '}, $parameters{ $name }, qq{'\n}
                );
            }

        }

        return 1;

    },
);

1;
